# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class GCPNodeOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'service_account': 'ServiceAccount',
        'disks': 'list[GCPNodeDisk]',
        'labels': 'dict(str, str)'
    }

    attribute_map = {
        'service_account': 'serviceAccount',
        'disks': 'disks',
        'labels': 'labels'
    }

    def __init__(self, service_account=None, disks=None, labels=None, local_vars_configuration=None):  # noqa: E501
        """GCPNodeOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._service_account = None
        self._disks = None
        self._labels = None
        self.discriminator = None

        if service_account is not None:
            self.service_account = service_account
        if disks is not None:
            self.disks = disks
        if labels is not None:
            self.labels = labels

    @property
    def service_account(self):
        """Gets the service_account of this GCPNodeOptions.  # noqa: E501


        :return: The service_account of this GCPNodeOptions.  # noqa: E501
        :rtype: ServiceAccount
        """
        return self._service_account

    @service_account.setter
    def service_account(self, service_account):
        """Sets the service_account of this GCPNodeOptions.


        :param service_account: The service_account of this GCPNodeOptions.  # noqa: E501
        :type: ServiceAccount
        """

        self._service_account = service_account

    @property
    def disks(self):
        """Gets the disks of this GCPNodeOptions.  # noqa: E501

        [GCE] Disk configurations for GCE cluster nodes.  # noqa: E501

        :return: The disks of this GCPNodeOptions.  # noqa: E501
        :rtype: list[GCPNodeDisk]
        """
        return self._disks

    @disks.setter
    def disks(self, disks):
        """Sets the disks of this GCPNodeOptions.

        [GCE] Disk configurations for GCE cluster nodes.  # noqa: E501

        :param disks: The disks of this GCPNodeOptions.  # noqa: E501
        :type: list[GCPNodeDisk]
        """

        self._disks = disks

    @property
    def labels(self):
        """Gets the labels of this GCPNodeOptions.  # noqa: E501

        [GCE] Labels for GCE cluster nodes.  # noqa: E501

        :return: The labels of this GCPNodeOptions.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this GCPNodeOptions.

        [GCE] Labels for GCE cluster nodes.  # noqa: E501

        :param labels: The labels of this GCPNodeOptions.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GCPNodeOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GCPNodeOptions):
            return True

        return self.to_dict() != other.to_dict()
